@@ -23,7 +23,7 @@ class NodeException(str):
         return cls(v)
 
     def __repr__(self):
-        return f"Exception({self.value})"
+        return f"Exception({str(self)})"
 
 
 EventValue = Union[Tuple[Any, ...], NodeException]
